@@ -20,17 +20,10 @@ class Job:
 			json = {'task': self.task, 'trigger': self.trigger}
 			response = requests.post(url, headers=self.headers, json=json)
 			self.uuid = response.json().get('uuid')
-			# TODO return self?
 			return response.json()
 		
 		return self
 
-	def delete(self):
-		url = f'{API_URL}/jobs/{self.uuid}'
-		response = requests.delete(url, headers=self.headers)
-		# TODO return self?
-		return response.json()
-
 	# Jobs
 
 	@classmethod
@@ -38,7 +31,6 @@ class Job:
 		url = f'{API_URL}/jobs'
 		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
 		response = requests.get(url, headers=headers)
-		# TODO cast into Job(s)?
 		return response.json()
 
 	@classmethod
@@ -46,7 +38,13 @@ class Job:
 		url = f'{API_URL}/jobs/{uuid}'
 		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
 		response = requests.get(url, headers=headers)
-		# TODO cast into Job?
+		return response.json()
+
+	@classmethod
+	def delete(cls, uuid):
+		url = f'{API_URL}/jobs/{uuid}'
+		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
+		response = requests.delete(url, headers=headers)
 		return response.json()
 
 	# Triggers
